Colour Notation Systems
=======================

Munsell Renotation System
-------------------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    munsell_colour_to_xyY
    xyY_to_munsell_colour

**Dataset**

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    MUNSELL_COLOURS

Munsell Value
-------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    munsell_value
    MUNSELL_VALUE_METHODS

Priest, Gibson and MacNicholas (1920)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

``colour.notation``

.. currentmodule:: colour.notation

.. autosummary::
    :toctree: generated/

    munsell_value_Priest1920

Munsell, Sloan and Godlove (1933)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

``colour.notation``

.. currentmodule:: colour.notation

.. autosummary::
    :toctree: generated/

    munsell_value_Munsell1933

Moon and Spencer (1943)
~~~~~~~~~~~~~~~~~~~~~~~

``colour.notation``

.. currentmodule:: colour.notation

.. autosummary::
    :toctree: generated/

    munsell_value_Moon1943

Saunderson and Milner (1944)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~

``colour.notation``

.. currentmodule:: colour.notation

.. autosummary::
    :toctree: generated/

    munsell_value_Saunderson1944

Ladd and Pinney (1955)
~~~~~~~~~~~~~~~~~~~~~~

``colour.notation``

.. currentmodule:: colour.notation

.. autosummary::
    :toctree: generated/

    munsell_value_Ladd1955

McCamy (1987)
~~~~~~~~~~~~~

``colour.notation``

.. currentmodule:: colour.notation

.. autosummary::
    :toctree: generated/

    munsell_value_McCamy1987

ASTM D1535-08e1
~~~~~~~~~~~~~~~

``colour.notation``

.. currentmodule:: colour.notation

.. autosummary::
    :toctree: generated/

    munsell_value_ASTMD1535

Hexadecimal Representation
--------------------------

``colour.notation``

.. currentmodule:: colour.notation

.. autosummary::
    :toctree: generated/

    RGB_to_HEX
    HEX_to_RGB

Web Colours
-----------

``colour.notation``

.. currentmodule:: colour.notation

.. autosummary::
    :toctree: generated/

    CSS_COLOR_3_BASIC
    CSS_COLOR_3_EXTENDED
    CSS_COLOR_3
    keyword_to_RGB_CSSColor3
